VideoSubmissionData class

Constructors

VideoSubmissionData({required String name, required String location, required File videoFile})

Properties

hashCode int
The hash code for this object.
no setterinherited
location String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoFile File
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited